@@ -1,4 +1,4 @@
-# $Id: __init__.py 8595 2020-12-15 23:06:58Z milde $
+# $Id: __init__.py 9037 2022-03-05 23:31:10Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -10,16 +10,12 @@ __docformat__ = 'reStructuredText'
 
 import re
 import codecs
-import sys
 from importlib import import_module
 
 from docutils import nodes, parsers
-from docutils.utils import split_escaped_whitespace, escape2null, unescape
+from docutils.utils import split_escaped_whitespace, escape2null
 from docutils.parsers.rst.languages import en as _fallback_language_module
 
-if sys.version_info >= (3, 0):
-    unichr = chr  # noqa
-
 
 _directive_registry = {
       'attention': ('admonitions', 'Attention'),
@@ -44,7 +40,7 @@ _directive_registry = {
       'pull-quote': ('body', 'PullQuote'),
       'compound': ('body', 'Compound'),
       'container': ('body', 'Container'),
-      #'questions': ('body', 'question_list'),
+      # 'questions': ('body', 'question_list'),
       'table': ('tables', 'RSTTable'),
       'csv-table': ('tables', 'CSVTable'),
       'list-table': ('tables', 'ListTable'),
@@ -54,11 +50,11 @@ _directive_registry = {
       'sectnum': ('parts', 'Sectnum'),
       'header': ('parts', 'Header'),
       'footer': ('parts', 'Footer'),
-      #'footnotes': ('parts', 'footnotes'),
-      #'citations': ('parts', 'citations'),
+      # 'footnotes': ('parts', 'footnotes'),
+      # 'citations': ('parts', 'citations'),
       'target-notes': ('references', 'TargetNotes'),
-      'meta': ('html', 'Meta'),
-      #'imagemap': ('html', 'imagemap'),
+      'meta': ('misc', 'Meta'),
+      # 'imagemap': ('html', 'imagemap'),
       'raw': ('misc', 'Raw'),
       'include': ('misc', 'Include'),
       'replace': ('misc', 'Replace'),
@@ -68,7 +64,8 @@ _directive_registry = {
       'default-role': ('misc', 'DefaultRole'),
       'title': ('misc', 'Title'),
       'date': ('misc', 'Date'),
-      'restructuredtext-test-directive': ('misc', 'TestDirective'),}
+      'restructuredtext-test-directive': ('misc', 'TestDirective'),
+      }
 """Mapping of directive name to (module name, class name).  The
 directive name is canonical & must be lowercase.  Language-dependent
 names are defined in the ``language`` subpackage."""
@@ -76,6 +73,7 @@ names are defined in the ``language`` subpackage."""
 _directives = {}
 """Cache of imported directives."""
 
+
 def directive(directive_name, language_module, document):
     """
     Locate and return a directive function from its language-dependent name.
@@ -134,6 +132,7 @@ def directive(directive_name, language_module, document):
         return None, messages
     return directive, messages
 
+
 def register_directive(name, directive):
     """
     Register a nonstandard application-defined directive function.
@@ -141,6 +140,7 @@ def register_directive(name, directive):
     """
     _directives[name] = directive
 
+
 def flag(argument):
     """
     Check for a valid flag option (no argument) and return ``None``.
@@ -153,6 +153,7 @@ def flag(argument):
     else:
         return None
 
+
 def unchanged_required(argument):
     """
     Return the argument text, unchanged.
@@ -165,6 +166,7 @@ def unchanged_required(argument):
     else:
         return argument  # unchanged!
 
+
 def unchanged(argument):
     """
     Return the argument text, unchanged.
@@ -173,10 +175,11 @@ def unchanged(argument):
     No argument implies empty string ("").
     """
     if argument is None:
-        return u''
+        return ''
     else:
         return argument  # unchanged!
 
+
 def path(argument):
     """
     Return the path argument unwrapped (with newlines removed).
@@ -187,8 +190,8 @@ def path(argument):
     if argument is None:
         raise ValueError('argument required but none supplied')
     else:
-        path = ''.join([s.strip() for s in argument.splitlines()])
-        return path
+        return ''.join(s.strip() for s in argument.splitlines())
+
 
 def uri(argument):
     """
@@ -201,8 +204,9 @@ def uri(argument):
         raise ValueError('argument required but none supplied')
     else:
         parts = split_escaped_whitespace(escape2null(argument))
-        uri = ' '.join(''.join(unescape(part).split()) for part in parts)
-        return uri
+        return ' '.join(''.join(nodes.unescape(part).split())
+                        for part in parts)
+
 
 def nonnegative_int(argument):
     """
@@ -214,6 +218,7 @@ def nonnegative_int(argument):
         raise ValueError('negative value; must be positive or zero')
     return value
 
+
 def percentage(argument):
     """
     Check for an integer percentage value with optional percent sign.
@@ -225,8 +230,10 @@ def percentage(argument):
         pass
     return nonnegative_int(argument)
 
+
 length_units = ['em', 'ex', 'px', 'in', 'cm', 'mm', 'pt', 'pc']
 
+
 def get_measure(argument, units):
     """
     Check for a positive argument of one of the units and return a
@@ -242,12 +249,14 @@ def get_measure(argument, units):
     except (AttributeError, ValueError):
         raise ValueError(
             'not a positive measure of one of the following units:\n%s'
-            % ' '.join(['"%s"' % i for i in units]))
+            % ' '.join('"%s"' % i for i in units))
     return match.group(1) + match.group(2)
 
+
 def length_or_unitless(argument):
     return get_measure(argument, length_units + [''])
 
+
 def length_or_percentage_or_unitless(argument, default=''):
     """
     Return normalized string of a length or percentage unit.
@@ -274,6 +283,7 @@ def length_or_percentage_or_unitless(argument, default=''):
             # raise ValueError with list of valid units:
             return get_measure(argument, length_units + ['%'])
 
+
 def class_option(argument):
     """
     Convert the argument into a list of ID-compatible strings and return it.
@@ -292,9 +302,11 @@ def class_option(argument):
         class_names.append(class_name)
     return class_names
 
+
 unicode_pattern = re.compile(
     r'(?:0x|x|\\x|U\+?|\\u)([0-9a-f]+)$|&#x([0-9a-f]+);$', re.IGNORECASE)
 
+
 def unicode_code(code):
     r"""
     Convert a Unicode character code to a Unicode character.
@@ -308,17 +320,18 @@ def unicode_code(code):
     """
     try:
         if code.isdigit():                  # decimal number
-            return unichr(int(code))
+            return chr(int(code))
         else:
             match = unicode_pattern.match(code)
             if match:                       # hex number
                 value = match.group(1) or match.group(2)
-                return unichr(int(value, 16))
+                return chr(int(value, 16))
             else:                           # other text
                 return code
     except OverflowError as detail:
         raise ValueError('code too large (%s)' % detail)
 
+
 def single_char_or_unicode(argument):
     """
     A single character is returned as-is.  Unicode characters codes are
@@ -330,6 +343,7 @@ def single_char_or_unicode(argument):
                          'a Unicode code' % char)
     return char
 
+
 def single_char_or_whitespace_or_unicode(argument):
     """
     As with `single_char_or_unicode`, but "tab" and "space" are also supported.
@@ -343,6 +357,7 @@ def single_char_or_whitespace_or_unicode(argument):
         char = single_char_or_unicode(argument)
     return char
 
+
 def positive_int(argument):
     """
     Converts the argument into an integer.  Raises ValueError for negative,
@@ -353,6 +368,7 @@ def positive_int(argument):
         raise ValueError('negative or zero value; must be positive')
     return value
 
+
 def positive_int_list(argument):
     """
     Converts a space- or comma-separated list of values into a Python list
@@ -367,9 +383,10 @@ def positive_int_list(argument):
         entries = argument.split()
     return [positive_int(entry) for entry in entries]
 
+
 def encoding(argument):
     """
-    Verfies the encoding argument by lookup.
+    Verifies the encoding argument by lookup.
     (Directive option conversion function.)
 
     Raises ValueError for unknown encodings.
@@ -380,6 +397,7 @@ def encoding(argument):
         raise ValueError('unknown encoding: "%s"' % argument)
     return argument
 
+
 def choice(argument, values):
     """
     Directive option utility function, supplied to enable options whose
@@ -406,14 +424,16 @@ def choice(argument, values):
         raise ValueError('"%s" unknown; choose from %s'
                          % (argument, format_values(values)))
 
+
 def format_values(values):
-    return '%s, or "%s"' % (', '.join(['"%s"' % s for s in values[:-1]]),
+    return '%s, or "%s"' % (', '.join('"%s"' % s for s in values[:-1]),
                             values[-1])
 
+
 def value_or(values, other):
     """
     Directive option conversion function.
-    
+
     The argument can be any of `values` or `argument_type`.
     """
     def auto_or_other(argument):
@@ -423,16 +443,18 @@ def value_or(values, other):
             return other(argument)
     return auto_or_other
 
+
 def parser_name(argument):
     """
     Return a docutils parser whose name matches the argument.
     (Directive option conversion function.)
 
     Return `None`, if the argument evaluates to `False`.
+    Raise `ValueError` if importing the parser module fails.
     """
     if not argument:
         return None
     try:
         return parsers.get_parser_class(argument)
-    except ImportError:
-        raise ValueError('Unknown parser name "%s".'%argument)
+    except ImportError as err:
+        raise ValueError(str(err))
