@@ -8,5 +8,9 @@ parser_name = "rst"
 writer_name = "latex"
 
 # Extra setting we need
-settings_overrides['literal_block_env'] = 'Verbatim'
 settings_overrides['syntax_highlight'] = 'none'
+settings_overrides['stylesheet'] = 'docutils'
+settings_overrides['legacy_column_widths'] = True
+settings_overrides['use_latex_citations'] = False
+
+settings_overrides['literal_block_env'] = 'Verbatim'
