@@ -1,6 +1,6 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# $Id: test_get_parser_class.py 8356 2019-08-26 16:44:19Z milde $
+# $Id: test_get_parser_class.py 9038 2022-03-05 23:31:46Z milde $
 # Author: grubert abadger1999
 # Maintainer: docutils-develop@lists.sourceforge.net
 # Copyright: This module has been placed in the public domain.
@@ -8,26 +8,29 @@
 """
 test get_parser_class
 """
-from __future__ import absolute_import
 
-from . import DocutilsTestSupport
+if __name__ == '__main__':
+    import __init__  # noqa: F401
+from test_parsers import DocutilsTestSupport
 from docutils.parsers import get_parser_class
 
+
 class GetParserClassTestCase(DocutilsTestSupport.StandardTestCase):
 
     def test_registered_parser(self):
-        rdr = get_parser_class('rst')
+        get_parser_class('rst')
         # raises ImportError on failure
 
     def test_bogus_parser(self):
-        self.assertRaises(ImportError,
-                          get_parser_class, 'nope')
+        with self.assertRaises(ImportError):
+            get_parser_class('nope')
 
     def test_local_parser(self):
         # requires local-parser.py in test directory (testroot)
-        wr = get_parser_class('local-parser')
+        get_parser_class('local-parser')
+        # raises ImportError on failure
+
 
 if __name__ == '__main__':
     import unittest
     unittest.main()
-
