@@ -1,15 +1,16 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# $Id: test_filter.py 8356 2019-08-26 16:44:19Z milde $
+# $Id: test_filter.py 9037 2022-03-05 23:31:10Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
 Tests for docutils.transforms.components.Filter.
 """
-from __future__ import absolute_import
 
-from . import DocutilsTestSupport
+if __name__ == '__main__':
+    import __init__  # noqa: F401
+from test_transforms import DocutilsTestSupport
 from docutils.parsers.rst import Parser
 
 
@@ -19,6 +20,7 @@ def suite():
     s.generateTests(totest)
     return s
 
+
 totest = {}
 
 totest['meta'] = ((), [
