@@ -1,20 +1,20 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# $Id: test_strip_elements_with_class.py 8481 2020-01-31 08:17:24Z milde $
+# $Id: test_strip_elements_with_class.py 9037 2022-03-05 23:31:10Z milde $
 # Author: Guenter Milde <milde@users.sf.net>
 # Copyright: This module has been placed in the public domain.
 
 """
 Tests for docutils.transforms.universal.StripClassesAndElements.
 """
-from __future__ import absolute_import
 
 if __name__ == '__main__':
-    import __init__
+    import __init__  # noqa: F401
 from test_transforms import DocutilsTestSupport
 from docutils.parsers.rst import Parser
 from docutils.transforms.universal import StripClassesAndElements
 
+
 def suite():
     parser = Parser()
     s = DocutilsTestSupport.TransformTestSuite(parser,
@@ -23,6 +23,7 @@ def suite():
     s.generateTests(totest)
     return s
 
+
 totest = {}
 
 totest['strip_spam'] = ((StripClassesAndElements,), [
@@ -39,9 +40,9 @@ this is ham
 
 .. code::
    :class: spam
-   
+   \n\
    print("spam")
-   
+   \n\
 .. image:: spam.jpg
    :class: spam
 
