@@ -1,6 +1,6 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# $Id: test_get_writer_class.py 8356 2019-08-26 16:44:19Z milde $
+# $Id: test_get_writer_class.py 9038 2022-03-05 23:31:46Z milde $
 # Author: grubert
 # Maintainer: docutils-develop@lists.sourceforge.net
 # Copyright: This module has been placed in the public domain.
@@ -8,28 +8,29 @@
 """
 test get_writer_class
 """
-from __future__ import absolute_import
 
-from . import DocutilsTestSupport
+if __name__ == '__main__':
+    import __init__  # noqa: F401
+from test_writers import DocutilsTestSupport
 from docutils.writers import get_writer_class
 
 
 class GetWriterClassTestCase(DocutilsTestSupport.StandardTestCase):
-    #tests = ( ('manpage', 1), ('nope', 0), ('dummy-writer', 1))
 
     def test_registered_writer(self):
-        wr = get_writer_class('manpage')
+        get_writer_class('manpage')
         # raises ImportError on failure
 
     def test_bogus_writer(self):
-        self.assertRaises(ImportError,
-                          get_writer_class, 'nope')
+        with self.assertRaises(ImportError):
+            get_writer_class('nope')
 
     def test_local_writer(self):
         # requires local-writer.py in test directory (testroot)
-        wr = get_writer_class('local-writer')
+        get_writer_class('local-writer')
+        # raises ImportError on failure
+
 
 if __name__ == '__main__':
     import unittest
     unittest.main()
-
